summaryrefslogtreecommitdiffstats
path: root/kplato
diff options
context:
space:
mode:
Diffstat (limited to 'kplato')
-rw-r--r--kplato/kptaccountspanelbase.ui2
-rw-r--r--kplato/kptaccountsview.cc10
-rw-r--r--kplato/kptcalendar.cc8
-rw-r--r--kplato/kptcalendareditbase.cc8
-rw-r--r--kplato/kptcalendarlistdialog.cc4
-rw-r--r--kplato/kptcalendarpanel.cc36
-rw-r--r--kplato/kptcalendarpanel.h8
-rw-r--r--kplato/kptcanvasitem.cc8
-rw-r--r--kplato/kptconfigdialog.cc2
-rw-r--r--kplato/kptdatetable.cc14
-rw-r--r--kplato/kptdatetable.h10
-rw-r--r--kplato/kptdoublelistviewbase.cc6
-rw-r--r--kplato/kptdoublelistviewbase.h2
-rw-r--r--kplato/kptdurationwidget.ui20
-rw-r--r--kplato/kptganttview.cc6
-rw-r--r--kplato/kptintervaleditbase.ui2
-rw-r--r--kplato/kptmainprojectdialog.cc2
-rw-r--r--kplato/kptmainprojectpanelbase.ui4
-rw-r--r--kplato/kptmilestoneprogresspanel.cc2
-rw-r--r--kplato/kptmilestoneprogresspanelbase.ui2
-rw-r--r--kplato/kptnode.cc2
-rw-r--r--kplato/kptproject.cc2
-rw-r--r--kplato/kptprojectdialogbase.ui4
-rw-r--r--kplato/kptreportview.cc2
-rw-r--r--kplato/kptresource.cc2
-rw-r--r--kplato/kptresourceappointmentsview.cc2
-rw-r--r--kplato/kptresourceview.cc6
-rw-r--r--kplato/kptresourceview.h2
-rw-r--r--kplato/kptsummarytaskgeneralpanelbase.ui4
-rw-r--r--kplato/kpttaskappointmentsview.cc2
-rw-r--r--kplato/kpttaskappointmentsview.ui.h2
-rw-r--r--kplato/kpttaskcostpanelbase.ui8
-rw-r--r--kplato/kpttaskdefaultpanel.cc2
-rw-r--r--kplato/kpttaskgeneralpanel.cc2
-rw-r--r--kplato/kpttaskgeneralpanelbase.ui2
-rw-r--r--kplato/kpttaskprogresspanel.cc4
-rw-r--r--kplato/kpttaskprogresspanelbase.ui16
-rw-r--r--kplato/kpttaskresourcespanelbase.ui2
-rw-r--r--kplato/kptwbsdefinition.cc2
-rw-r--r--kplato/kptwbsdefinitionpanelbase.ui2
-rw-r--r--kplato/kptxmlloaderobject.h4
-rw-r--r--kplato/relationpanel.ui6
-rw-r--r--kplato/resourcedialogbase.ui6
-rw-r--r--kplato/resourcespanelbase.ui4
-rw-r--r--kplato/standardworktimedialogbase.ui2
45 files changed, 124 insertions, 124 deletions
diff --git a/kplato/kptaccountspanelbase.ui b/kplato/kptaccountspanelbase.ui
index e76a6129..c1091745 100644
--- a/kplato/kptaccountspanelbase.ui
+++ b/kplato/kptaccountspanelbase.ui
@@ -13,7 +13,7 @@
<height>234</height>
</rect>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>350</width>
<height>220</height>
diff --git a/kplato/kptaccountsview.cc b/kplato/kptaccountsview.cc
index 9825d9c2..5fd3c7cd 100644
--- a/kplato/kptaccountsview.cc
+++ b/kplato/kptaccountsview.cc
@@ -99,7 +99,7 @@ AccountsView::AccountsView(Project &project, View *view, TQWidget *parent)
m_project(project),
m_accounts(project.accounts()) {
- m_date = TQDate::tqcurrentDate();
+ m_date = TQDate::currentDate();
m_period = 0;
m_periodTexts<<i18n("Day")<<i18n("Week")<<i18n("Month");
m_cumulative = false;
@@ -110,10 +110,10 @@ AccountsView::AccountsView(Project &project, View *view, TQWidget *parent)
m_label = new Label(this);
m_label->setFrameShape(TQLabel::StyledPanel);
m_label->setFrameShadow(TQLabel::Sunken);
- m_label->tqsetAlignment(int(TQLabel::WordBreak | TQLabel::AlignVCenter));
+ m_label->setAlignment(int(TQLabel::WordBreak | TQLabel::AlignVCenter));
lay2->addWidget(m_label);
m_changeBtn = new TQPushButton(i18n("Configure..."), this);
- m_changeBtn->tqsetSizePolicy(TQSizePolicy((TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, m_changeBtn->sizePolicy().hasHeightForWidth()));
+ m_changeBtn->setSizePolicy(TQSizePolicy((TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, m_changeBtn->sizePolicy().hasHeightForWidth()));
lay2->addWidget(m_changeBtn);
lay1->addLayout(lay2);
@@ -139,7 +139,7 @@ void AccountsView::zoom(double zoom) {
}
void AccountsView::init() {
- m_date = TQDate::tqcurrentDate();
+ m_date = TQDate::currentDate();
m_period = 0;
initAccList(m_accounts.accountList());
}
@@ -378,7 +378,7 @@ bool AccountsView::setContext(Context::Accountsview &context) {
//m_dlv->setSizes(list); //NOTE: This doesn't always work!
m_date = context.date;
if (!m_date.isValid())
- m_date = TQDate::tqcurrentDate();
+ m_date = TQDate::currentDate();
m_period = context.period;
m_cumulative = context.cumulative;
setContextClosedItems(context);
diff --git a/kplato/kptcalendar.cc b/kplato/kptcalendar.cc
index 486c3dac..56ba7380 100644
--- a/kplato/kptcalendar.cc
+++ b/kplato/kptcalendar.cc
@@ -225,11 +225,11 @@ Duration CalendarDay::effort(const TQTime &start, const TQTime &end) {
for (; it.current(); ++it) {
//kdDebug()<<k_funcinfo<<"Interval: "<<it.current()->first.toString()<<" - "<<it.current()->second.toString()<<endl;
if (end > it.current()->first && start < it.current()->second) {
- DateTime dtStart(TQDate::tqcurrentDate(), start);
+ DateTime dtStart(TQDate::currentDate(), start);
if (start < it.current()->first) {
dtStart.setTime(it.current()->first);
}
- DateTime dtEnd(TQDate::tqcurrentDate(), end);
+ DateTime dtEnd(TQDate::currentDate(), end);
if (end > it.current()->second) {
dtEnd.setTime(it.current()->second);
}
@@ -282,8 +282,8 @@ Duration CalendarDay::duration() const {
Duration dur;
TQPtrListIterator<TQPair<TQTime, TQTime> > it = m_workingIntervals;
for (; it.current(); ++it) {
- DateTime start(TQDate::tqcurrentDate(), it.current()->first);
- DateTime end(TQDate::tqcurrentDate(), it.current()->second);
+ DateTime start(TQDate::currentDate(), it.current()->first);
+ DateTime end(TQDate::currentDate(), it.current()->second);
dur += end - start;
}
return dur;
diff --git a/kplato/kptcalendareditbase.cc b/kplato/kptcalendareditbase.cc
index aaa6fab0..a7b36ef1 100644
--- a/kplato/kptcalendareditbase.cc
+++ b/kplato/kptcalendareditbase.cc
@@ -54,7 +54,7 @@ CalendarEditBase::CalendarEditBase( TQWidget* parent, const char* name, WFlags f
groupBox2->tqlayout()->setSpacing( 6 );
groupBox2->tqlayout()->setMargin( 6 );
groupBox2Layout = new TQGridLayout( groupBox2->tqlayout() );
- groupBox2Layout->tqsetAlignment( TQt::AlignTop );
+ groupBox2Layout->setAlignment( TQt::AlignTop );
calendarPanel = new CalendarPanel( groupBox2, "calendarPanel" );
@@ -65,7 +65,7 @@ CalendarEditBase::CalendarEditBase( TQWidget* parent, const char* name, WFlags f
day->tqlayout()->setSpacing( 6 );
day->tqlayout()->setMargin( 6 );
dayLayout = new TQVBoxLayout( day->tqlayout() );
- dayLayout->tqsetAlignment( TQt::AlignTop );
+ dayLayout->setAlignment( TQt::AlignTop );
tqlayout8 = new TQHBoxLayout( 0, 0, 6, "tqlayout8");
@@ -81,7 +81,7 @@ CalendarEditBase::CalendarEditBase( TQWidget* parent, const char* name, WFlags f
groupBox4->tqlayout()->setSpacing( 6 );
groupBox4->tqlayout()->setMargin( 6 );
groupBox4Layout = new TQVBoxLayout( groupBox4->tqlayout() );
- groupBox4Layout->tqsetAlignment( TQt::AlignTop );
+ groupBox4Layout->setAlignment( TQt::AlignTop );
intervalList = new TQListView( groupBox4, "intervalList" );
intervalList->addColumn( tr2i18n( "Work Interval" ) );
@@ -109,7 +109,7 @@ CalendarEditBase::CalendarEditBase( TQWidget* parent, const char* name, WFlags f
groupBox2Layout->addWidget( day, 1, 1 );
CalendarEditBaseLayout->addWidget( groupBox2 );
languageChange();
- resize( TQSize(540, 340).expandedTo(tqminimumSizeHint()) );
+ resize( TQSize(540, 340).expandedTo(minimumSizeHint()) );
clearWState( WState_Polished );
}
diff --git a/kplato/kptcalendarlistdialog.cc b/kplato/kptcalendarlistdialog.cc
index b5a2d59c..c10a34b5 100644
--- a/kplato/kptcalendarlistdialog.cc
+++ b/kplato/kptcalendarlistdialog.cc
@@ -182,8 +182,8 @@ CalendarListDialog::CalendarListDialog(Project &p, TQWidget *parent, const char
if (f) {
dia->calendarList->setSelected(f, true);
}
- //kdDebug()<<"size="<<size().width()<<"x"<<size().height()<<" hint="<<tqsizeHint().width()<<"x"<<tqsizeHint().height()<<endl;
- resize(TQSize(725, 388).expandedTo(tqminimumSizeHint()));
+ //kdDebug()<<"size="<<size().width()<<"x"<<size().height()<<" hint="<<sizeHint().width()<<"x"<<sizeHint().height()<<endl;
+ resize(TQSize(725, 388).expandedTo(minimumSizeHint()));
setMainWidget(dia);
enableButtonOK(false);
diff --git a/kplato/kptcalendarpanel.h b/kplato/kptcalendarpanel.h
index 9cf6c4f8..0c72d763 100644
--- a/kplato/kptcalendarpanel.h
+++ b/kplato/kptcalendarpanel.h
@@ -54,7 +54,7 @@ public:
/** The usual constructor. The given date will be displayed
* initially.
**/
- CalendarPanel(TQWidget *parent=0, TQDate=TQDate::tqcurrentDate(), const char *name=0, WFlags f=0);
+ CalendarPanel(TQWidget *parent=0, TQDate=TQDate::currentDate(), const char *name=0, WFlags f=0);
/**
* Standard qt widget constructor. The initial date will be the
@@ -73,9 +73,9 @@ public:
* size hint, try adding 28 to each of the reported numbers of
* pixels.
**/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
- TQSize tqminimumSizeHint() const { return tqsizeHint(); }
+ TQSize minimumSizeHint() const { return sizeHint(); }
/**
* Sets the date.
*
@@ -113,7 +113,7 @@ public:
/**
* By calling this method with @p enable = true, CalendarPanel will show
* a little close-button in the upper button-row. Clicking the
- * close-button will cause the CalendarPanel's tqtopLevelWidget()'s close()
+ * close-button will cause the CalendarPanel's topLevelWidget()'s close()
* method being called. This is mostly useful for toplevel datepickers
* without a window manager decoration.
* @see #hasCloseButton
diff --git a/kplato/kptcanvasitem.cc b/kplato/kptcanvasitem.cc
index 59690e3a..9cd6654e 100644
--- a/kplato/kptcanvasitem.cc
+++ b/kplato/kptcanvasitem.cc
@@ -70,15 +70,15 @@ int PertNodeItem::RTTI = 2000;
void PertNodeItem::setVisible(bool yes)
{
//kdDebug()<<k_funcinfo<<m_node.name()<<endl;
- TQCanvasPolygon::tqsetVisible(yes);
+ TQCanvasPolygon::setVisible(yes);
TQCanvasItemList list = canvas()->allItems();
TQCanvasItemList::Iterator it = list.begin();
for (; it != list.end(); ++it)
{
if ( *it == m_name )
- m_name->tqsetVisible(yes);
+ m_name->setVisible(yes);
if ( *it == m_leader )
- m_leader->tqsetVisible(yes);
+ m_leader->setVisible(yes);
}
}
@@ -274,7 +274,7 @@ PertRelationItem::PertRelationItem( PertCanvas *view, PertNodeItem *parent, Pert
{
//kdDebug()<<k_funcinfo<<"Parent="<<parent->node().name()<<" Child="<<child->node().name()<<endl;
draw();
- tqsetVisible(true);
+ setVisible(true);
}
PertRelationItem::~PertRelationItem()
diff --git a/kplato/kptconfigdialog.cc b/kplato/kptconfigdialog.cc
index 729d6443..2186d400 100644
--- a/kplato/kptconfigdialog.cc
+++ b/kplato/kptconfigdialog.cc
@@ -41,7 +41,7 @@ namespace KPlato
// little helper stolen from kmail/kword
static inline TQPixmap loadIcon( const char * name ) {
return KGlobal::instance()->iconLoader()
- ->loadIcon( TQString::tqfromLatin1(name), KIcon::NoGroup, KIcon::SizeMedium );
+ ->loadIcon( TQString::fromLatin1(name), KIcon::NoGroup, KIcon::SizeMedium );
}
diff --git a/kplato/kptdatetable.cc b/kplato/kptdatetable.cc
index afa06591..44f91500 100644
--- a/kplato/kptdatetable.cc
+++ b/kplato/kptdatetable.cc
@@ -88,7 +88,7 @@ DateTable::DateTable(TQWidget *parent, TQDate date_, const char* name, WFlags f)
setFontSize(10);
if(!date_.isValid()) {
kdError() <<k_funcinfo<<"Given date is invalid, using current date." << endl;
- date_=TQDate::tqcurrentDate();
+ date_=TQDate::currentDate();
}
setFocusPolicy( TQ_StrongFocus );
setNumCols(7+m_dateStartCol); // 7 days a week + maybe 1 for weeknumbers
@@ -232,7 +232,7 @@ void DateTable::paintDay(TQPainter *painter, int row, int col) {
painter->lineTo(w-1, h-1);
}
// then paint square if current date
- if (d == TQDate::tqcurrentDate()) {
+ if (d == TQDate::currentDate()) {
painter->setPen(colorLine);
painter->drawRect(1, 1, w-2, h-2);
}
@@ -317,7 +317,7 @@ void DateTable::keyPressEvent( TQKeyEvent *e ) {
return;
}
if ( e->key() == TQt::Key_N ) {
- setDate(TQDate::tqcurrentDate());
+ setDate(TQDate::currentDate());
return;
}
if ( e->key() == TQt::Key_Control ) {
@@ -353,7 +353,7 @@ void DateTable::setFontSize(int size) {
maxCell.setHeight(TQMAX(maxCell.height(), rect.height()));
}
// ----- compare with a real wide number and add some space:
- rect=metrics.boundingRect(TQString::tqfromLatin1("88"));
+ rect=metrics.boundingRect(TQString::fromLatin1("88"));
maxCell.setWidth(TQMAX(maxCell.width()+2, rect.width()));
maxCell.setHeight(TQMAX(maxCell.height()+4, rect.height()));
}
@@ -582,12 +582,12 @@ void DateTable::focusOutEvent( TQFocusEvent *e ) {
TQGridView::focusOutEvent( e );
}
-TQSize DateTable::tqsizeHint() const {
+TQSize DateTable::sizeHint() const {
if(maxCell.height()>0 && maxCell.width()>0) {
return TQSize(maxCell.width()*numCols()+2*frameWidth(),
(maxCell.height()+2)*numRows()+2*frameWidth());
} else {
- //kdDebug() << "DateTable::tqsizeHint: obscure failure - " << endl;
+ //kdDebug() << "DateTable::sizeHint: obscure failure - " << endl;
return TQSize(-1, -1);
}
}
@@ -794,7 +794,7 @@ DateInternalMonthPicker::DateInternalMonthPicker
}
TQSize
-DateInternalMonthPicker::tqsizeHint() const
+DateInternalMonthPicker::sizeHint() const
{
return TQSize((max.width()+6)*numCols()+2*frameWidth(),
(max.height()+6)*numRows()+2*frameWidth());
diff --git a/kplato/kptdoublelistviewbase.cc b/kplato/kptdoublelistviewbase.cc
index 2780d166..23c0c80b 100644
--- a/kplato/kptdoublelistviewbase.cc
+++ b/kplato/kptdoublelistviewbase.cc
@@ -388,9 +388,9 @@ DoubleListViewBase::DoubleListViewBase(TQWidget *parent, bool description)
}
-TQSize DoubleListViewBase::tqsizeHint() const {
- //kdDebug()<<k_funcinfo<<tqminimumSizeHint()<<endl;
- return tqminimumSizeHint(); //HACK: koshell splitter problem
+TQSize DoubleListViewBase::sizeHint() const {
+ //kdDebug()<<k_funcinfo<<minimumSizeHint()<<endl;
+ return minimumSizeHint(); //HACK: koshell splitter problem
}
void DoubleListViewBase::clearSlaveList() {
diff --git a/kplato/kptdoublelistviewbase.h b/kplato/kptdoublelistviewbase.h
index aaaaf305..e56b21b9 100644
--- a/kplato/kptdoublelistviewbase.h
+++ b/kplato/kptdoublelistviewbase.h
@@ -83,7 +83,7 @@ public:
void setFormat(int fieldwidth=0, char fmt='f', int prec=0);
void setMasterFormat(int fieldwidth=0, char fmt='f', int prec=0);
void setSlaveFormat(int fieldwidth=0, char fmt='f', int prec=0);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
class MasterListItem;
class SlaveListItem : public KListViewItem {
diff --git a/kplato/kptdurationwidget.ui b/kplato/kptdurationwidget.ui
index a923dab4..e437fa58 100644
--- a/kplato/kptdurationwidget.ui
+++ b/kplato/kptdurationwidget.ui
@@ -20,7 +20,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -48,13 +48,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32676</width>
<height>20</height>
@@ -106,13 +106,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>50</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>70</width>
<height>32767</height>
@@ -163,7 +163,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -202,7 +202,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -252,7 +252,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -302,13 +302,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>32</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
diff --git a/kplato/kptganttview.cc b/kplato/kptganttview.cc
index 925598f9..e37ab194 100644
--- a/kplato/kptganttview.cc
+++ b/kplato/kptganttview.cc
@@ -73,8 +73,8 @@ public:
MyKDGanttView(TQWidget *parent, const char *name)
: KDGanttView(parent, name) {
}
- virtual TQSize tqsizeHint() const {
- return tqminimumSizeHint(); //HACK: koshell splitter tqminimumSize problem
+ virtual TQSize sizeHint() const {
+ return minimumSizeHint(); //HACK: koshell splitter minimumSize problem
}
};
@@ -1048,7 +1048,7 @@ void GanttView::print(KPrinter &prt) {
p.drawRect(0,0,metrics.width(),metrics.height());
TQString text;
int hei = 0;
- text = KGlobal::locale()->formatDateTime(TQDateTime::tqcurrentDateTime());
+ text = KGlobal::locale()->formatDateTime(TQDateTime::currentDateTime());
TQRect r = p.boundingRect(metrics.width()-1,0,0,0, TQt::AlignRight, text );
p.drawText( r, TQt::AlignRight, text );
hei = r.height();
diff --git a/kplato/kptintervaleditbase.ui b/kplato/kptintervaleditbase.ui
index 76b00dc4..4e847442 100644
--- a/kplato/kptintervaleditbase.ui
+++ b/kplato/kptintervaleditbase.ui
@@ -86,7 +86,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>51</width>
<height>21</height>
diff --git a/kplato/kptmainprojectdialog.cc b/kplato/kptmainprojectdialog.cc
index a9f40ae0..ee8ed8fc 100644
--- a/kplato/kptmainprojectdialog.cc
+++ b/kplato/kptmainprojectdialog.cc
@@ -39,7 +39,7 @@ MainProjectDialog::MainProjectDialog(Project &p, TQWidget *parent, const char *n
setMainWidget(panel);
enableButtonOK(false);
- resize( TQSize(500, 410).expandedTo(tqminimumSizeHint()));
+ resize( TQSize(500, 410).expandedTo(minimumSizeHint()));
connect(panel, TQT_SIGNAL(obligatedFieldsFilled(bool)), TQT_SLOT(enableButtonOK(bool)));
}
diff --git a/kplato/kptmainprojectpanelbase.ui b/kplato/kptmainprojectpanelbase.ui
index f6622781..108c6f14 100644
--- a/kplato/kptmainprojectpanelbase.ui
+++ b/kplato/kptmainprojectpanelbase.ui
@@ -88,7 +88,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>270</width>
<height>20</height>
@@ -99,7 +99,7 @@
<property name="name">
<cstring>wbs</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>20</width>
<height>0</height>
diff --git a/kplato/kptmilestoneprogresspanel.cc b/kplato/kptmilestoneprogresspanel.cc
index b5c1af0a..67b88443 100644
--- a/kplato/kptmilestoneprogresspanel.cc
+++ b/kplato/kptmilestoneprogresspanel.cc
@@ -85,7 +85,7 @@ void MilestoneProgressPanelImpl::slotChanged() {
void MilestoneProgressPanelImpl::slotFinishedChanged(bool state) {
if (state) {
if (!finishTime->dateTime().isValid()) {
- finishTime->setDateTime(TQDateTime::tqcurrentDateTime());
+ finishTime->setDateTime(TQDateTime::currentDateTime());
}
}
enableWidgets();
diff --git a/kplato/kptmilestoneprogresspanelbase.ui b/kplato/kptmilestoneprogresspanelbase.ui
index 97a06f4d..9856eca5 100644
--- a/kplato/kptmilestoneprogresspanelbase.ui
+++ b/kplato/kptmilestoneprogresspanelbase.ui
@@ -43,7 +43,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kplato/kptnode.cc b/kplato/kptnode.cc
index 1da218e6..9f8d5a0d 100644
--- a/kplato/kptnode.cc
+++ b/kplato/kptnode.cc
@@ -96,7 +96,7 @@ void Node::init() {
m_visitedForward = false;
m_visitedBackward = false;
- m_dateOnlyStartDate = m_dateOnlyEndDate = TQDate::tqcurrentDate();
+ m_dateOnlyStartDate = m_dateOnlyEndDate = TQDate::currentDate();
m_dateOnlyDuration.addDays(1);
m_runningAccount = 0;
diff --git a/kplato/kptproject.cc b/kplato/kptproject.cc
index 9379de4a..13c44cb3 100644
--- a/kplato/kptproject.cc
+++ b/kplato/kptproject.cc
@@ -56,7 +56,7 @@ Project::Project(Node *parent)
void Project::init() {
if (m_parent == 0) {
// set sensible defaults for a project wo parent
- m_constraintStartTime = TQDateTime(TQDate::tqcurrentDate(), TQTime());
+ m_constraintStartTime = TQDateTime(TQDate::currentDate(), TQTime());
m_constraintEndTime = TQDateTime(m_constraintStartTime.addDays(1));
}
m_calendars.setAutoDelete(true);
diff --git a/kplato/kptprojectdialogbase.ui b/kplato/kptprojectdialogbase.ui
index 2dab71fe..6ff94658 100644
--- a/kplato/kptprojectdialogbase.ui
+++ b/kplato/kptprojectdialogbase.ui
@@ -153,7 +153,7 @@
<property name="name">
<cstring>schedulerDate</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>200</height>
@@ -201,7 +201,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>121</width>
<height>20</height>
diff --git a/kplato/kptreportview.cc b/kplato/kptreportview.cc
index 655d1907..3bdab2b2 100644
--- a/kplato/kptreportview.cc
+++ b/kplato/kptreportview.cc
@@ -83,7 +83,7 @@ public:
if (!tag.contains('.')) {
// global tags
if (tag == "currentdate") {
- return l->formatDate(TQDate::tqcurrentDate(), true);
+ return l->formatDate(TQDate::currentDate(), true);
}
return TQString();
}
diff --git a/kplato/kptresource.cc b/kplato/kptresource.cc
index 448074ae..2c218fe9 100644
--- a/kplato/kptresource.cc
+++ b/kplato/kptresource.cc
@@ -203,7 +203,7 @@ Resource::Resource(Project *project) : m_project(project), m_schedules(), m_work
m_type = Type_Work;
m_units = 100; // %
- m_availableFrom = DateTime(TQDate::tqcurrentDate());
+ m_availableFrom = DateTime(TQDate::currentDate());
m_availableUntil = TQDateTime(m_availableFrom.addYears(2));
cost.normalRate = 100;
diff --git a/kplato/kptresourceappointmentsview.cc b/kplato/kptresourceappointmentsview.cc
index 4b6d7a44..5531156f 100644
--- a/kplato/kptresourceappointmentsview.cc
+++ b/kplato/kptresourceappointmentsview.cc
@@ -200,7 +200,7 @@ void ResourceAppointmentsView::print(KPrinter &/*printer*/) {
// m_dlv->setSizes(list);
// m_date = context.date;
// if (!m_date.isValid())
-// m_date = TQDate::tqcurrentDate();
+// m_date = TQDate::currentDate();
// m_period = context.period;
// m_cumulative = context.cumulative;
//
diff --git a/kplato/kptresourceview.h b/kplato/kptresourceview.h
index b3049ed3..7154af8f 100644
--- a/kplato/kptresourceview.h
+++ b/kplato/kptresourceview.h
@@ -71,7 +71,7 @@ class ResourceItemPrivate;
virtual bool setContext(Context::Resourceview &context);
virtual void getContext(Context::Resourceview &context) const;
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
void setShowAppointments(bool on) { m_showAppointments = on; }
diff --git a/kplato/kptsummarytaskgeneralpanelbase.ui b/kplato/kptsummarytaskgeneralpanelbase.ui
index 57dd2654..57e25e51 100644
--- a/kplato/kptsummarytaskgeneralpanelbase.ui
+++ b/kplato/kptsummarytaskgeneralpanelbase.ui
@@ -13,7 +13,7 @@
<height>250</height>
</rect>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>400</width>
<height>0</height>
@@ -127,7 +127,7 @@ This is not limited to persons available in a resource group but can be anyone.
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/kplato/kpttaskappointmentsview.cc b/kplato/kpttaskappointmentsview.cc
index 5e96030e..387e75e5 100644
--- a/kplato/kpttaskappointmentsview.cc
+++ b/kplato/kpttaskappointmentsview.cc
@@ -151,7 +151,7 @@ void TaskAppointmentsView::print(KPrinter &/*printer*/) {
// m_dlv->setSizes(list);
// m_date = context.date;
// if (!m_date.isValid())
-// m_date = TQDate::tqcurrentDate();
+// m_date = TQDate::currentDate();
// m_period = context.period;
// m_cumulative = context.cumulative;
//
diff --git a/kplato/kpttaskappointmentsview.ui.h b/kplato/kpttaskappointmentsview.ui.h
index 7e090fb7..fe0cc9c9 100644
--- a/kplato/kpttaskappointmentsview.ui.h
+++ b/kplato/kpttaskappointmentsview.ui.h
@@ -90,7 +90,7 @@ void TaskAppointmentsView::init()
m_appList->setColumnAlignment(6, AlignRight);
m_task = 0;
- m_date->setDate(TQDate::tqcurrentDate());
+ m_date->setDate(TQDate::currentDate());
}
diff --git a/kplato/kpttaskcostpanelbase.ui b/kplato/kpttaskcostpanelbase.ui
index 38250f2b..9907a26a 100644
--- a/kplato/kpttaskcostpanelbase.ui
+++ b/kplato/kpttaskcostpanelbase.ui
@@ -65,7 +65,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -129,7 +129,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -193,7 +193,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -212,7 +212,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kplato/kpttaskdefaultpanel.cc b/kplato/kpttaskdefaultpanel.cc
index 3fd5472b..bcaac757 100644
--- a/kplato/kpttaskdefaultpanel.cc
+++ b/kplato/kpttaskdefaultpanel.cc
@@ -81,7 +81,7 @@ void TaskDefaultPanel::setStartValues(Task &task, StandardWorktime *workTime) {
if (task.constraintStartTime().isValid()) {
setStartDateTime(task.constraintStartTime());
} else {
- TQDate date = TQDate::tqcurrentDate();
+ TQDate date = TQDate::currentDate();
setStartDateTime(TQDateTime(date, TQTime()));
}
if (task.constraintEndTime().isValid()) {
diff --git a/kplato/kpttaskgeneralpanel.cc b/kplato/kpttaskgeneralpanel.cc
index 6dd1dad2..f8970675 100644
--- a/kplato/kpttaskgeneralpanel.cc
+++ b/kplato/kpttaskgeneralpanel.cc
@@ -93,7 +93,7 @@ void TaskGeneralPanel::setStartValues(Task &task, StandardWorktime *workTime) {
if (task.constraintStartTime().isValid()) {
setStartDateTime(task.constraintStartTime());
} else {
- TQDate date = TQDate::tqcurrentDate();
+ TQDate date = TQDate::currentDate();
setStartDateTime(TQDateTime(date, TQTime()));
}
if (task.constraintEndTime().isValid()) {
diff --git a/kplato/kpttaskgeneralpanelbase.ui b/kplato/kpttaskgeneralpanelbase.ui
index 1d153a02..e61f316e 100644
--- a/kplato/kpttaskgeneralpanelbase.ui
+++ b/kplato/kpttaskgeneralpanelbase.ui
@@ -121,7 +121,7 @@ This is not limited to persons available in a resource group but can be anyone.
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/kplato/kpttaskprogresspanel.cc b/kplato/kpttaskprogresspanel.cc
index e8cfb570..bed7a3c2 100644
--- a/kplato/kpttaskprogresspanel.cc
+++ b/kplato/kpttaskprogresspanel.cc
@@ -147,7 +147,7 @@ void TaskProgressPanelImpl::slotChanged() {
void TaskProgressPanelImpl::slotStartedChanged(bool state) {
if (state) {
- startTime->setDateTime(TQDateTime::tqcurrentDateTime());
+ startTime->setDateTime(TQDateTime::currentDateTime());
percentFinished->setValue(0);
}
enableWidgets();
@@ -158,7 +158,7 @@ void TaskProgressPanelImpl::slotFinishedChanged(bool state) {
if (state) {
percentFinished->setValue(100);
if (!finishTime->dateTime().isValid()) {
- finishTime->setDateTime(TQDateTime::tqcurrentDateTime());
+ finishTime->setDateTime(TQDateTime::currentDateTime());
}
}
enableWidgets();
diff --git a/kplato/kpttaskprogresspanelbase.ui b/kplato/kpttaskprogresspanelbase.ui
index 00d23dda..2bcb2eac 100644
--- a/kplato/kpttaskprogresspanelbase.ui
+++ b/kplato/kpttaskprogresspanelbase.ui
@@ -85,7 +85,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>61</width>
<height>41</height>
@@ -187,7 +187,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>200</width>
<height>20</height>
@@ -204,7 +204,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>41</width>
<height>70</height>
@@ -247,7 +247,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -279,7 +279,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -303,7 +303,7 @@
<property name="enabled">
<bool>true</bool>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>320</width>
<height>0</height>
@@ -320,7 +320,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>59</width>
<height>20</height>
@@ -365,7 +365,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kplato/kpttaskresourcespanelbase.ui b/kplato/kpttaskresourcespanelbase.ui
index dfa3b818..52fa42d0 100644
--- a/kplato/kpttaskresourcespanelbase.ui
+++ b/kplato/kpttaskresourcespanelbase.ui
@@ -49,7 +49,7 @@
<property name="name">
<cstring>groupList</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>0</height>
diff --git a/kplato/kptwbsdefinition.cc b/kplato/kptwbsdefinition.cc
index fd6b48aa..f33d355c 100644
--- a/kplato/kptwbsdefinition.cc
+++ b/kplato/kptwbsdefinition.cc
@@ -140,7 +140,7 @@ const TQCString RNThousands[] = {"", "m", "mm", "mmm"};
TQString WBSDefinition::toRoman( int n, bool upper )
{
if ( n >= 0 ) {
- TQString s = TQString::tqfromLatin1( RNThousands[ ( n / 1000 ) ] +
+ TQString s = TQString::fromLatin1( RNThousands[ ( n / 1000 ) ] +
RNHundreds[ ( n / 100 ) % 10 ] +
RNTens[ ( n / 10 ) % 10 ] +
RNUnits[ ( n ) % 10 ] );
diff --git a/kplato/kptwbsdefinitionpanelbase.ui b/kplato/kptwbsdefinitionpanelbase.ui
index 4656ce4e..afe672f8 100644
--- a/kplato/kptwbsdefinitionpanelbase.ui
+++ b/kplato/kptwbsdefinitionpanelbase.ui
@@ -145,7 +145,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
diff --git a/kplato/kptxmlloaderobject.h b/kplato/kptxmlloaderobject.h
index 814af40b..c8ddc7a5 100644
--- a/kplato/kptxmlloaderobject.h
+++ b/kplato/kptxmlloaderobject.h
@@ -46,14 +46,14 @@ public:
void startLoad() {
m_timer.start();
- m_starttime = TQDateTime::tqcurrentDateTime();
+ m_starttime = TQDateTime::currentDateTime();
m_errors = m_warnings = 0;
m_log.clear();
addMsg(TQString("Loading started at %1").tqarg(m_starttime.toString()));
}
void stopLoad() {
m_elapsed = m_timer.elapsed();
- addMsg(TQString("Loading finished at %1, took %2").tqarg(TQDateTime::tqcurrentDateTime().toString()).tqarg(formatElapsed()));
+ addMsg(TQString("Loading finished at %1, took %2").tqarg(TQDateTime::currentDateTime().toString()).tqarg(formatElapsed()));
}
TQDateTime lastLoaded() const { return m_starttime; }
int elapsed() const { return m_elapsed; }
diff --git a/kplato/relationpanel.ui b/kplato/relationpanel.ui
index 409a52f9..bfa7fbdc 100644
--- a/kplato/relationpanel.ui
+++ b/kplato/relationpanel.ui
@@ -24,7 +24,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -47,7 +47,7 @@
<property name="name">
<cstring>groupBox1</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>300</width>
<height>0</height>
@@ -236,7 +236,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
diff --git a/kplato/resourcedialogbase.ui b/kplato/resourcedialogbase.ui
index 8107e9ac..3fb04b75 100644
--- a/kplato/resourcedialogbase.ui
+++ b/kplato/resourcedialogbase.ui
@@ -79,7 +79,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>100</width>
<height>32767</height>
@@ -261,7 +261,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -359,7 +359,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/kplato/resourcespanelbase.ui b/kplato/resourcespanelbase.ui
index 8428e29c..5af1ac5d 100644
--- a/kplato/resourcespanelbase.ui
+++ b/kplato/resourcespanelbase.ui
@@ -13,7 +13,7 @@
<height>227</height>
</rect>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>500</width>
<height>200</height>
@@ -173,7 +173,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>220</height>
diff --git a/kplato/standardworktimedialogbase.ui b/kplato/standardworktimedialogbase.ui
index 61f4fddb..7d33ffb3 100644
--- a/kplato/standardworktimedialogbase.ui
+++ b/kplato/standardworktimedialogbase.ui
@@ -200,7 +200,7 @@ when there is no calendar defined for a resource.</string>
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>160</width>
<height>210</height>
diff --git a/kplato/kptcalendarpanel.cc b/kplato/kptcalendarpanel.cc
index e6322944..48b4f9ca 100644
--- a/kplato/kptcalendarpanel.cc
+++ b/kplato/kptcalendarpanel.cc
@@ -65,7 +65,7 @@ CalendarPanel::CalendarPanel(TQWidget *parent, TQDate dt, const char *name, WFla
CalendarPanel::CalendarPanel( TQWidget *parent, const char *name )
: TQFrame(parent,name)
{
- init( TQDate::tqcurrentDate() );
+ init( TQDate::currentDate() );
}
void CalendarPanel::init( const TQDate &dt )
@@ -96,10 +96,10 @@ void CalendarPanel::init( const TQDate &dt )
setFontSize(10);
line->setValidator(val);
line->installEventFilter( this );
- yearForward->setPixmap(BarIcon(TQString::tqfromLatin1("2rightarrow")));
- yearBackward->setPixmap(BarIcon(TQString::tqfromLatin1("2leftarrow")));
- monthForward->setPixmap(BarIcon(TQString::tqfromLatin1("1rightarrow")));
- monthBackward->setPixmap(BarIcon(TQString::tqfromLatin1("1leftarrow")));
+ yearForward->setPixmap(BarIcon(TQString::fromLatin1("2rightarrow")));
+ yearBackward->setPixmap(BarIcon(TQString::fromLatin1("2leftarrow")));
+ monthForward->setPixmap(BarIcon(TQString::fromLatin1("1rightarrow")));
+ monthBackward->setPixmap(BarIcon(TQString::fromLatin1("1leftarrow")));
setDate(dt); // set button texts
connect(table, TQT_SIGNAL(dateChanged(TQDate)), TQT_SLOT(dateChangedSlot(TQDate)));
connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
@@ -164,7 +164,7 @@ CalendarPanel::resizeEvent(TQResizeEvent*)
// ----- calculate button row height:
for(count=0; count<NoOfButtons; ++count) {
if ( buttons[count] ) { // closeButton may be 0L
- sizes[count]=buttons[count]->tqsizeHint();
+ sizes[count]=buttons[count]->sizeHint();
buttonHeight=TQMAX(buttonHeight, sizes[count].height());
}
else
@@ -175,7 +175,7 @@ CalendarPanel::resizeEvent(TQResizeEvent*)
for(count=0; count<NoOfButtons; ++count) {
if(buttons[count]==selectMonth) {
TQSize metricBound = tqstyle().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
- sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().tqpixelMetric(TQStyle::PM_ButtonMargin)));
+ sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().pixelMetric(TQStyle::PM_ButtonMargin)));
}
}
// ----- center buttons
@@ -195,7 +195,7 @@ CalendarPanel::resizeEvent(TQResizeEvent*)
x+=w;
}
// ----- place the line edit for direct input:
- sizes[0]=line->tqsizeHint();
+ sizes[0]=line->sizeHint();
int week_width=d->selectWeek->fontMetrics().width(i18n("Week XX"))+((d->closeButton != 0L) ? 50 : 20);
line->setGeometry(0, height()-sizes[0].height(), width()-week_width, sizes[0].height());
d->selectWeek->setGeometry(width()-week_width, height()-sizes[0].height(), week_width, sizes[0].height());
@@ -285,7 +285,7 @@ CalendarPanel::selectWeekClicked()
PopupFrame* popup = new PopupFrame(this);
DateInternalWeekSelector* picker = new DateInternalWeekSelector(fontsize, popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
picker->setFocus();
@@ -322,7 +322,7 @@ CalendarPanel::selectMonthClicked()
PopupFrame* popup = new PopupFrame(this);
DateInternalMonthPicker* picker = new DateInternalMonthPicker(fontsize, popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
picker->setFocus();
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
@@ -352,7 +352,7 @@ CalendarPanel::selectYearClicked()
PopupFrame* popup = new PopupFrame(this);
DateInternalYearSelector* picker = new DateInternalYearSelector(fontsize, popup);
// -----
- picker->resize(picker->tqsizeHint());
+ picker->resize(picker->sizeHint());
popup->setMainWidget(picker);
connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
picker->setFocus();
@@ -409,9 +409,9 @@ CalendarPanel::lineEnterPressed()
}
TQSize
-CalendarPanel::tqsizeHint() const
+CalendarPanel::sizeHint() const
{
- TQSize tableSize=table->tqsizeHint();
+ TQSize tableSize=table->sizeHint();
TQWidget *buttons[]={
yearBackward,
monthBackward,
@@ -427,13 +427,13 @@ CalendarPanel::tqsizeHint() const
// ----- store the size hints:
for(count=0; count<NoOfButtons; ++count) {
if ( buttons[count] )
- sizes[count]=buttons[count]->tqsizeHint();
+ sizes[count]=buttons[count]->sizeHint();
else
sizes[count] = TQSize(0,0);
if(buttons[count]==selectMonth) {
TQSize metricBound = tqstyle().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
- cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().tqpixelMetric(TQStyle::PM_ButtonMargin));
+ cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::tqstyle().pixelMetric(TQStyle::PM_ButtonMargin));
} else {
cx+=sizes[count].width();
}
@@ -442,7 +442,7 @@ CalendarPanel::tqsizeHint() const
// ----- calculate width hint:
cx=TQMAX(cx, tableSize.width()); // line edit ignored
// ----- calculate height hint:
- cy+=tableSize.height()+line->tqsizeHint().height();
+ cy+=tableSize.height()+line->sizeHint().height();
return TQSize(cx, cy);
}
@@ -471,7 +471,7 @@ CalendarPanel::setFontSize(int s)
}
TQFontMetrics metrics(selectMonth->fontMetrics());
for(int i=1; i <= 12; ++i)
- { // maxMonthRect is used by tqsizeHint()
+ { // maxMonthRect is used by sizeHint()
r=metrics.boundingRect(KGlobal::locale()->calendar()->monthName(i, false));
maxMonthRect.setWidth(TQMAX(r.width(), maxMonthRect.width()));
maxMonthRect.setHeight(TQMAX(r.height(), maxMonthRect.height()));
@@ -490,7 +490,7 @@ CalendarPanel::setCloseButton( bool enable )
TQToolTip::add(d->closeButton, i18n("Close"));
d->closeButton->setPixmap( SmallIcon("remove") );
connect( d->closeButton, TQT_SIGNAL( clicked() ),
- tqtopLevelWidget(), TQT_SLOT( close() ) );
+ topLevelWidget(), TQT_SLOT( close() ) );
}
else {
delete d->closeButton;
diff --git a/kplato/kptdatetable.h b/kplato/kptdatetable.h
index 815a86e9..9cd992e3 100644
--- a/kplato/kptdatetable.h
+++ b/kplato/kptdatetable.h
@@ -104,11 +104,11 @@ public:
/**
* The size hint.
*/
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
/**
* The minimum size hint.
*/
- TQSize tqminimumSizeHint() const { return tqsizeHint(); }
+ TQSize minimumSizeHint() const { return sizeHint(); }
/**
* Return the result. 0 means no selection (reject()), 1..12 are the
* months.
@@ -260,7 +260,7 @@ public:
/**
* The constructor.
*/
- DateTable(TQWidget *parent=0, TQDate date=TQDate::tqcurrentDate(),
+ DateTable(TQWidget *parent=0, TQDate date=TQDate::currentDate(),
const char* name="DateTable", WFlags f=0);
/**
@@ -268,9 +268,9 @@ public:
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -268,9 +268,9 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/
diff --git a/kplato/kptresourceview.cc b/kplato/kptresourceview.cc
index d596ff44..40d4b7c9 100644
--- a/kplato/kptresourceview.cc
+++ b/kplato/kptresourceview.cc
@@ -268,7 +268,7 @@ protected:
p->translate( rleft, crtop );
//kdDebug()<<k_funcinfo<<"paintBranches: "<<current->i->text(0)<<endl;
- current->i->paintBranches( p, tqcolorGroup(), treeStepSize(),
+ current->i->paintBranches( p, colorGroup(), treeStepSize(),
rtop - crtop, r.height() );
p->restore();
}
@@ -362,8 +362,8 @@ public:
TQDate date;
};
-TQSize ResourceView::tqsizeHint() const {
- return tqminimumSizeHint(); // HACK: koshell splitter tqminimumSize problem
+TQSize ResourceView::sizeHint() const {
+ return minimumSizeHint(); // HACK: koshell splitter minimumSize problem
}
ResourceView::ResourceView(View *view, TQWidget *parent)